@@ -13,19 +13,13 @@ doc = paci.__doc__
 class TestConfigure(unittest.TestCase):
 
     def test_prints_the_welcome_msg(self):
-        configure = Configure(["test"])
+        configure = Configure({'configure': True, '--no-choice': False, '--silent': True, '--main-registry': False, '--fallback-registry': False})
 
         with patch('sys.stdout', new_callable=StringIO) as sysout:
-            with patch("paci.commands.configure.input", return_value=False) as m:
+            with patch("paci.helpers.display_helper.std_input", return_value='') as m:
                 configure.run()
 
         self.assertIn('Lets configure a new settings.yml for paci!', sysout.getvalue())
 
-    def test_asks_for_basedir(self):
-        configure = Configure(["test"])
-
-        with patch('sys.stdout', new_callable=StringIO) as sysout:
-            with patch('sys.stdin', new_callable=StringIO) as sysin:
-                configure.run()
-
-        self.assertIn('basedir (defaults to', sysin.getvalue())
+if __name__ == '__main__':
+    unittest.main()
